@@ -97,11 +97,13 @@ class CrudSchema:
         return self.get()
 
     def put(self, **data):
+        res = []
         for item in self.queryset:
             for key, value in data.items():
                 setattr(item, key, value)
             item.full_clean()
-        self.queryset.update(**data)
+        for item in res:
+            item.save()
         return self.get()
 
     def delete(self):
